@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: AttachSettings.py 10775 2018-02-07 09:28:57Z David $
+# $Id: AttachSettings.py 10804 2018-03-02 03:53:42Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2018-02-07 17:28:57 +0800 (Wed, 07 Feb 2018) $
-# $Revision: 10775 $
+# $Date: 2018-03-02 11:53:42 +0800 (Fri, 02 Mar 2018) $
+# $Revision: 10804 $
 
 import os
 
@@ -48,24 +48,22 @@ def attachSettings(settingsDict):
         # Attach INSTALLED_APPS.
         #=======================================================================
 
-        installedApps = settingsDict.get('THEOPHRASTUS_INSTALLED_APPS', [
-            # for modification of newsletter_historic.html in 
-            # newsletter_extension, we change order of installed_apps between
-            # newsletter_extension and emencia.django.newsletter.
-            
-            'Theophrastus.newsletter_extension',
-            'emencia.django.newsletter',
-            'Theophrastus',
-            'Theophrastus.cloud',
-            'Theophrastus.editor',
-            'Theophrastus.statistics',
-            'Theophrastus.document',
+        installedApps = settingsDict.get('THEOPHRASTUS_INSTALLED_APPS', [            
             # django-selectable
             'selectable',
             # django-modeladmin-reorder
-            'admin_reorder',     
+            'admin_reorder',  
+            
+            'emencia.django.newsletter',
+            # newsletter_extension uses cloud app to resend error newsletters.
+            'Theophrastus.cloud',
+            'Theophrastus.newsletter_extension',
+            'Theophrastus.editor',
+            'Theophrastus.statistics',
+            'Theophrastus.document',  
+            
         ])
-
+        
         if settingsDict.get('THEOPHRASTUS_ENABLE_INTEGRATION', False):
             installedApps.append('Theophrastus.integration')
             installedApps.append('Theophrastus.api')
