@@ -114,16 +114,16 @@ INSTALLED_APPS = (
     'tagging',
     'tinymce',
     'emencia.django.newsletter',
-    # 'Theophrastus.editor',
-    # 'Theophrastus.statistics',
-    # 'Theophrastus.cloud',
-    # 'Theophrastus.newsletter_extension',
-    # 'Theophrastus.document',
-    # 'Theophrastus.integration',
-    # 'Theophrastus.api',
+    'Theophrastus.editor',
+    'Theophrastus.statistics',
+    'Theophrastus.cloud',
+    'Theophrastus.newsletter_extension',
+    'Theophrastus.document',
+    'Theophrastus.integration',
+    'Theophrastus.api',
     # If your want do translate, you need to enable these:
     # 'editor',
-    'statistics',
+    # 'statistics',
     # 'cloud',
     # 'newsletter_extension',
     # 'document',
