@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Mailer.py 10775 2018-02-07 09:28:57Z David $
+# $Id: Mailer.py 10797 2018-03-01 02:31:02Z David $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -13,7 +13,7 @@
 #
 # $Author: David $ (Last)
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 10775 $
+# $Revision: 10797 $
 
 import os
 import random
@@ -46,7 +46,8 @@ from Iuppiter.Encoding import utf8
 from Iuno.cloud.mail import EmailBackend
 from Iuno.cloud.mail import SendMessageException, RetryAndSendException
 
-from Theophrastus.models import ContactMailingStatus, Newsletter
+from emencia.django.newsletter.models import ContactMailingStatus, Newsletter
+
 from Theophrastus.newsletter_extension.models import Header, Footer, ErrorMessage
 from Theophrastus.cloud.service import CloudService
 from Theophrastus.Utility import getComment, trackLinks
