@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 9579 2016-03-09 01:43:46Z Judy $
+# $Id: admin.py 10797 2018-03-01 02:31:02Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,15 +11,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Judy $
-# $Date: 2016-03-09 09:43:46 +0800 (三, 09  3 2016) $
-# $Revision: 9579 $
+# $Author: David $
+# $Date: 2018-03-01 10:31:02 +0800 (Thu, 01 Mar 2018) $
+# $Revision: 10797 $
 
 from django.contrib import admin
 from django.conf import settings
 
 if settings.DEBUG:
-    from Theophrastus.models import ContactMailingStatus, Link
+    from emencia.django.newsletter.models import ContactMailingStatus, Link
 
     admin.site.unregister(ContactMailingStatus)
     admin.site.unregister(Link)
@@ -37,8 +37,7 @@ from django.db import models
 from django.forms import Textarea
 
 from emencia.django.newsletter.admin.mailinglist import MailingListAdmin
-
-from Theophrastus.models import MailingList
+from emencia.django.newsletter.models import MailingList
 
 admin.site.unregister(MailingList)
 
