@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 9579 2016-03-09 01:43:46Z Judy $
+# $Id: models.py 10797 2018-03-01 02:31:02Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,15 +11,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Judy $
-# $Date: 2016-03-09 09:43:46 +0800 (Wed, 09 Mar 2016) $
-# $Revision: 9579 $
+# $Author: David $
+# $Date: 2018-03-01 10:31:02 +0800 (Thu, 01 Mar 2018) $
+# $Revision: 10797 $
 
 from django.db import models
 
 from Iuppiter.Model import BaseModelMixin
 
-from Theophrastus.models import Newsletter, Contact
+from emencia.django.newsletter.models import Newsletter, Contact
 
 class CloudMailInformation(models.Model, BaseModelMixin):
     """
