@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 10440 2017-11-05 12:25:48Z David $
+# $Id: views.py 10797 2018-03-01 02:31:02Z David $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-11-05 20:25:48 +0800 (Sun, 05 Nov 2017) $
-# $Revision: 10440 $
+# $Date: 2018-03-01 10:31:02 +0800 (Thu, 01 Mar 2018) $
+# $Revision: 10797 $
 
 import re
 import time
@@ -33,7 +33,8 @@ from Iuppiter.Logging import createDebugLogger
 
 from django.conf import settings
 
-from Theophrastus.models import ContactMailingStatus, Contact
+from emencia.django.newsletter.models import ContactMailingStatus, Contact
+
 from Theophrastus.cloud.service import CloudService
 from Theophrastus.cloud.Amazon import SES, SNS
 
