@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 9579 2016-03-09 01:43:46Z Judy $
+# $Id: urls.py 10806 2018-03-02 04:29:05Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Judy $
-# $Date: 2016-03-09 09:43:46 +0800 (三, 09  3 2016) $
-# $Revision: 9579 $
+# $Author: David $
+# $Date: 2018-03-02 12:29:05 +0800 (Fri, 02 Mar 2018) $
+# $Revision: 10806 $
 
 from django.conf.urls import url, patterns
 
@@ -22,9 +22,10 @@ from Theophrastus.editor import views
 urlpatterns = patterns('',
     url(r'^templates/(?P<name>[-\w]+)/', views.getTemplate,
         name='Theophrastus.views.getTemplate'),
-
     url(r'^upload/display/$', views.uploadFile,
         name='Theophrastus.views.uploadFile'),
     url(r'^upload/file/$', views.upload,
         name='Theophrastus.views.upload'),
+    url(r'^facebook/feed/complete/$', views.feedComplete,
+        name="Theophrastus.facebook.feed.complete"),
 )
