@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 10641 2017-12-12 18:08:04Z David $
+# $Id: forms.py 10816 2018-03-05 07:24:25Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-12-13 02:08:04 +0800 (Wed, 13 Dec 2017) $
-# $Revision: 10641 $
+# $Date: 2018-03-05 15:24:25 +0800 (Mon, 05 Mar 2018) $
+# $Revision: 10816 $
 
 from django import forms
 from django.forms.models import save_instance
@@ -114,8 +114,8 @@ class GroupMappingTableForm(forms.ModelForm):
                              fail_message, commit, construct=False)
     save.alters_data = True
 
-from Theophrastus.admin import NewsletterTinyMCEForm
-from Theophrastus.models import MailingList
+from Theophrastus.editor.admin import NewsletterTinyMCEForm
+from emencia.django.newsletter.models import MailingList
 
 class NewsletterIntegrationForm(NewsletterTinyMCEForm):
     def __init__(self, *args, **kwargs):
