@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10639 2017-12-12 12:04:16Z David $
+# $Id: __init__.py 10797 2018-03-01 02:31:02Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-12-12 20:04:16 +0800 (Tue, 12 Dec 2017) $
-# $Revision: 10639 $
+# $Date: 2018-03-01 10:31:02 +0800 (Thu, 01 Mar 2018) $
+# $Revision: 10797 $
 
 import os
 import re
@@ -30,8 +30,10 @@ from Iuppiter.Service import BaseService
 
 from Iuppiter import debug
 
+from emencia.django.newsletter.models import Contact, Newsletter, \
+                                             MailingList, Attachment
+
 from Theophrastus.integration import models
-from Theophrastus.models import Contact, Newsletter, MailingList, Attachment
 from Theophrastus.Utility import _slugify
 
 from Theophrastus.cloud.service import CloudService
