@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 10771 2018-02-06 15:12:39Z David $
+# $Id: views.py 10806 2018-03-02 04:29:05Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -13,7 +13,7 @@
 #
 # $Author: David $
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 10771 $
+# $Revision: 10806 $
 
 from django.shortcuts import render_to_response, get_object_or_404
 from django.utils.translation import ugettext_lazy as _
@@ -24,15 +24,19 @@ from django.shortcuts import redirect
 from django.conf import settings
 from django.contrib.admin.views.decorators import staff_member_required
 from django.template import RequestContext
+from django.contrib.auth.decorators import login_required
 
 from Iuppiter.dispatch import ThreadPool
 from Iuppiter.extension.views import jsonpCallback
 from Iuppiter.Logging import createLogger
 
-from Theophrastus.models import Newsletter, ContactMailingStatus, Contact
+from emencia.django.newsletter.models import Newsletter, MailingList, \
+                                             ContactMailingStatus, Contact
+
 from Theophrastus.cloud.Mailer import CloudMailer
 from Theophrastus.newsletter_extension.models import Header, Footer, ErrorMessage
 from Theophrastus.cloud.service import CloudService
+from Theophrastus.Utility import _slugify
 
 @staff_member_required
 @jsonpCallback(noPadding=True)
@@ -126,9 +130,9 @@ def resendErrorContact(request, newsletterId):
 
         context['sendConfirm'] = _('Resend error emails finish')
     else:
-        context['information'] = _('All errors have resent')
+        context['information'] = _('All errors have been resent')
 
-    return render_to_response('newsletter/newsletter_historic.html',
+    return render_to_response('NewsletterHistoric.html',
                               context, context_instance=RequestContext(request))
 
 
@@ -173,3 +177,64 @@ def viewErrorDetails(request, slug, contactMailingStatusId):
         context_instance=RequestContext(request)
     )
 
+@login_required
+def viewNewsletterHistoric(request, slug):
+    """Display the historic of a newsletter"""
+    opts = Newsletter._meta
+    newsletter = get_object_or_404(Newsletter, slug=slug)
+
+    context = {'title': _('Historic of %s') % newsletter.__unicode__(),
+               'original': newsletter,
+               'opts': opts,
+               'object_id': newsletter.pk,
+               'app_label': opts.app_label}
+    return render_to_response('NewsletterHistoric.html',
+                              context, context_instance=RequestContext(request))
+
+# Theophrastus/static/js/Newsletter.js
+# Theophrastus/templates/admin/newsletter/newsletter/change_form.html
+@jsonpCallback(noPadding=True)
+def getSlugName(request):
+    """
+    Get slug name.
+
+    @param request Request instance.
+    """
+    title = request.GET.get('title', '')
+    if title:
+        return {'slug': _slugify(title)}
+    else:
+        return {}
+
+# Theophrastus/static/js/Newsletter.js
+# Theophrastus/templates/admin/newsletter/newsletter/change_form.html
+@jsonpCallback()
+def getMailingListInfo(request):
+    """
+    Get MailingList information.
+
+    @param request Request instance.
+    """
+    mailingListId = request.GET.get('mailingList', '')
+    newsletterIds = request.GET.get('newsletters', '')
+    newsletterIds = newsletterIds.split('_')
+    try:
+        if mailingListId:
+            mailingList = MailingList.objects.get(id=mailingListId)
+            return {
+                'subscribersCount': mailingList.subscribers_count(),
+                'name': mailingList.name
+            }
+        elif newsletterIds:
+            info = []
+            for n in Newsletter.objects.filter(id__in=newsletterIds):
+                mailingList = n.mailing_list
+                info.append({
+                    'subscribersCount': mailingList.subscribers_count(),
+                    'name': n.title
+                })
+
+            return {'info': info}
+    except Exception as e:
+        pass
+    return {'error': str(e)}
\ No newline at end of file
