@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 10436 2017-11-05 03:14:46Z David $
+# $Id: urls.py 10806 2018-03-02 04:29:05Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,13 +12,10 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-11-05 11:14:46 +0800 (Sun, 05 Nov 2017) $
-# $Revision: 10436 $
+# $Date: 2018-03-02 12:29:05 +0800 (Fri, 02 Mar 2018) $
+# $Revision: 10806 $
 
 from django.conf.urls import url, include, patterns
-from newsletter_extension import views as newsletterExtensionViews 
-
-import views
 
 urlpatterns = patterns('',
     # Editor.
@@ -39,14 +36,6 @@ urlpatterns = patterns('',
     url(r'^subscribers/',
         include('Theophrastus.statistics.urls.subscribers')),
 
-    # Other functionally.
-    url(r'^slug/get/$', views.getSlugName,
-        name="Theophrastus.views.getSlugName"),
-    url(r'^mailingList/get/$', views.getMailingListInfo,
-        name="Theophrastus.views.getMailingListInfo"),
-    url(r'^facebook/feed/complete/$', views.feedComplete,
-        name="Theophrastus.facebook.feed.complete"),
-
     # Integration.
     url(r'^integration/', include('Theophrastus.integration.urls')),
 
@@ -55,14 +44,4 @@ urlpatterns = patterns('',
 
     # django-selectable.
     url(r'^newsletters/selectable/', include('selectable.urls')),
-
-    # resend error contact.
-    url(r'^newsletters/resend/(?P<newsletterId>\w+)',
-        newsletterExtensionViews.resendErrorContact, name='resendErrorContact'),
-
-    url(
-        r'^tracking/historic/(?P<slug>[-\w]+)/errors/'
-        r'(?P<contactMailingStatusId>\w+)',
-        newsletterExtensionViews.viewErrorDetails,
-        name='Theophrastus.newsletter_extension.views.viewErrorDetails'),
 )
